#
# spec file for package guile1
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define guilemaj    2
%define guilemin    2
%define guilevers   %{guilemaj}.%{guilemin}
%define libgver     1
%define gsuff       %{guilemaj}_%{guilemin}-%{libgver}
Name:           guile1
Version:        2.2.6
Release:        bp154.3.3.1
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        GFDL-1.3-only AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/Scheme
URL:            https://www.gnu.org/software/guile/
Source0:        guile-%{version}.tar.xz
#Source1:        https://ftp.gnu.org/gnu/guile/guile-%%{version}.tar.xz.sig
Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=guile&download=1#/guile.keyring
Source3:        %{name}-rpmlintrc
# Fix the resulting /usr/lib64/pkgconfig/guile-2.2.pc
Patch0:         guile-2.2-gc_pkgconfig_private.patch
# test fails always with heap error
Patch1:         disable-test-out-of-memory.patch
BuildRequires:  flex
BuildRequires:  gmp-devel
BuildRequires:  libffi-devel
BuildRequires:  libltdl-devel
BuildRequires:  libunistring-devel
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(bdw-gc)
Requires(pre):  fileutils
Requires(pre):  sh-utils

%description
This package is to enable lilypond >= 2.24 to build for SLE and Leap
distributions due to CVE-2020-17354 and will be deleted when no longer
needed. It is installable alongside the normal guile executable.
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs.

%package -n libguile-%{gsuff}
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        GFDL-1.3-only AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/Scheme
Requires:       %{name}-modules-%{guilemaj}_%{guilemin} >= %{version}
# workaround for bnc#948804
Requires:       glibc-locale

%description -n libguile-%{gsuff}
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs. This package
contains the shared libraries.

%package modules-%{guilemaj}_%{guilemin}
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        GFDL-1.3-only AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/Scheme

%description modules-%{guilemaj}_%{guilemin}
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs. This package
contains guile modules.

%package -n lib%{name}-devel
Summary:        GNU's Ubiquitous Intelligent Language for Extension
License:        LGPL-2.1-or-later
Group:          Development/Languages/Scheme
Conflicts:      guile-devel
Requires:       gmp-devel
# following Requires needed because /usr/bin/guile-config needs /usr/bin/guile
Requires:       %{name} = %{version}
Requires:       libffi-devel
Requires:       libguile-%{gsuff} = %{version}
Requires:       libunistring-devel
Requires:       ncurses-devel
Requires:       readline-devel
Requires:       pkgconfig(bdw-gc)
Requires(post): %{install_info_prereq}
Requires(preun):%{install_info_prereq}

%description -n lib%{name}-devel
This is Guile, a portable, embeddable Scheme implementation written in
C. Guile provides a machine independent execution platform that can be
linked in as a library when building extensible programs.

%prep
%setup -q -n guile-%{version}
%autopatch -p1

# remove broken prebuilt objects
rm -r prebuilt/32-bit-big-endian

%build
#sed -i "s:GUILE_:GUILE1_:" guile-config/guile.m4
#sed -i "s:guile:guile1:" guile-config/guile.m4
autoreconf -i --force --verbose
%configure \
  --disable-static \
  --with-pic \
  --with-threads \
  --program-transform-name="s:guile:%{name}:" \
  --disable-silent-rules
# do sequential build for reproducible .go files = https://issues.guix.gnu.org/issue/20272 - boo#1102408
make
rm -f test-suite/tests/version.test

%check
LD_LIBRARY_PATH="." make %{?_smp_mflags} check

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/%{name}/site
find %{buildroot} -type f -name "*.la" -delete -print
# bug #874028
mkdir -p %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}
mv %{buildroot}%{_libdir}/libguile*-gdb.scm %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}/
# The next lines are to prevent conflict with guile
# use /usr/bin/guile1 instead of /usr/bin/guile
sed -i "s:${GUILE-guile}:${GUILE-guile1}:" %{buildroot}%{_datadir}/guile/*/scripts/*
sed -i "s:%{_bindir}/guile:%{_bindir}/%{name}:" %{buildroot}%{_bindir}/%{name}-config
# Don't forget guild
pushd %{buildroot}%{_bindir}
sed -i "s:%{_bindir}/guile:%{_bindir}/guile1:" guile1-config
sed -i 's/guild/guild1/' guild
mv guild guild1
ln -sf guild1 guile1-tools
popd
sed -i 's/\${bindir}\/guild/\${bindir}\/guild1/' %{buildroot}%{_libdir}/pkgconfig/guile-%{guilevers}.pc
rm -rf %{buildroot}%{_infodir}
mv %{buildroot}%{_datadir}/aclocal/guile{,1}.m4
#hack to fix pkg-config --modversion
sed -i 's/UNKNOWN/%{version}/' %{buildroot}%{_libdir}/pkgconfig/guile-%{guilevers}.pc

%post -n lib%{name}-devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}
%install_info --info-dir=%{_infodir} %{_infodir}/r5rs.info%{ext_info}

%preun -n lib%{name}-devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/r5rs.info%{ext_info}

%pre
# Remove obsolete files (< SuSE Linux 10.2)
rm -f var/adm/SuSEconfig/md5%{_datadir}/%{name}/*/slibcat
rm -f usr/share/%{name}/site/slibcat.SuSEconfig

%post -n libguile-%{gsuff} -p /sbin/ldconfig
%postun -n libguile-%{gsuff} -p /sbin/ldconfig

%files
%doc ABOUT-NLS AUTHORS ChangeLog GUILE-VERSION HACKING
%doc NEWS README THANKS
%{_bindir}/%{name}-tools
%{_bindir}/guild1
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%files -n libguile-%{gsuff}
%license LICENSE COPYING*
%{_libdir}/libguile-%{guilevers}.so.%{libgver}*

%files modules-%{guilemaj}_%{guilemin}
%{_libdir}/guile
# Own usr/share/guile1/site; side effect of not doing so is slib failing to install correctly.
%{_datadir}/%{name}
%{_datadir}/guile

%files -n lib%{name}-devel
%{_bindir}/%{name}-snarf
%{_bindir}/%{name}-config
%dir %{_includedir}/guile
%dir %{_includedir}/guile/%{guilevers}
%{_includedir}/guile/%{guilevers}/*
%{_datadir}/aclocal/guile1.m4
%{_libdir}/libguile-%{guilevers}.so
%{_libdir}/pkgconfig/guile-%{guilevers}.pc
# bug #874028
%dir %{_datadir}/gdb
%dir %{_datadir}/gdb/auto-load
%dir %{_datadir}/gdb/auto-load%{_prefix}
%dir %{_datadir}/gdb/auto-load/%{_libdir}
%{_datadir}/gdb/auto-load/%{_libdir}/libguile*-gdb.scm

%changelog
* Thu May 18 2023 Dave Plater <davejplater@gmail.com>
- Add service file to download release from git excluding the
  directory with commercial non free files.
* Mon May 15 2023 Dave Plater <davejplater@gmail.com>
- Update to version 2.2.6 to enable lilypond to be updated to
  2.24.1 to fix boo#1210502 and CVE-2020-17354.
- Removed the following obsolete patches:
  guile-1.6.10-mktemp.patch, guile1-CVE-2016-8605.patch,
  guile1-fix-texinfo-default-utf8.patch, guile-64bit.patch,
  guile-automake-1.13.patch, guile-gcc.patch,guile-popen-test.patch,
  guile-socket-test.patch, guile-texinfo.patch and reproducible.patch
- Added disable-test-out-of-memory.patch and
  guile-2.2-gc_pkgconfig_private.patch
* Mon Jun  8 2020 Dave Plater <davejplater@gmail.com>
- Fix build with gcc10 by removing optimization from the build flags
  Thanks to the lilypond devs.
* Sat Nov 23 2019 Dave Plater <davejplater@gmail.com>
- Fix build with new texinfo, which now assumes UTF8 in the texi
  files with guile1-fix-texinfo-default-utf8.patch.
* Fri Sep  6 2019 Dave Plater <davejplater@gmail.com>
- Disable link time optimisation to fix build.
* Mon Jan 16 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Mon Oct 17 2016 pgajdos@suse.com
- security update
  * CVE-2016-8605 [bsc#1004221]
    + guile1-CVE-2016-8605.patch
* Sat Mar 14 2015 mpluskal@suse.com
- Add gpg signature
- Use url for source
- Cleanup spec file with spec-cleaner
- Fix failures with texinfo 5.2
  * guile-texinfo.patch
* Sat Dec 14 2013 uweigand@de.ibm.com
- Make `socket.test' more robust
  * guile-socket-test.patch (from git branch_release-1-8)
* Mon Jun 17 2013 pgajdos@suse.com
- do not run test simultaneously
* Fri Apr 26 2013 mmeister@suse.com
- Added makeinfo BuildRequire to fix build with new automake
* Mon Mar  4 2013 pgajdos@suse.com
- build with new automake
  * automake-1.13.patch
* Mon Sep 10 2012 dimstar@opensuse.org
- Reauire the library packages from the main package: having the
  * .so symlinks in the main package forces us to install the libs
  as well, or we end up with dangling symlinks (thus, failing to
  actually dlopen the .so file, which was the main reason to move
  them to the main package. Fixes issues like bnc#779458).
* Tue Jul 31 2012 pgajdos@suse.com
- move *.so files into main package [bnc#772490]
* Tue Jan 31 2012 coolo@suse.com
- fix requires of devel package
* Wed Jan 25 2012 pgajdos@suse.com
- package /usr/share/aclocal/guile1.m4 (gnucash uses autoreconf)
  (GUILE_* macros renamed to GUILE1_*) [bnc#724917]
* Tue Jan 10 2012 pgajdos@suse.com
- added automake and libtool into buildrequires
- make guile1 and guile1-devel instalable along with guile and
  guile-devel [bnc#724917]:
  * removed info pages
  * removed /usr/share/aclocal/guile.m4
  * /usr/bin/guile* renamed to /usr/bin/guile1*
* Wed Sep 28 2011 davejplater@gmail.com
- Changed name to guile1 to create new package for factory, based
  on the 11.4 guile-1.8.7, to enable lilypond to build.
  Split off libraries and updated to version 1.8.8.
- Removed guile-testsuite-build.patch now incorporated in sources.
  Upstream changes :
  * Fix possible buffer overruns when parsing numbers
  * Fix random number generator on 64-bit platforms
  Previously the `scm_c_random' function would crash or return
  only 32-bit worth of randomness.  In addition, the new
  `scm_c_random64' function explicitly returns 64 bits of randomness.
  * Add missing range checks in `vector-move-left!' and
  `vector-move-right!'Previously these procedures could write past
  the end of a vector.
  * Avoid clash with system setjmp/longjmp on IA64
  * Don't dynamically link an extension that is already registered
  * Fix `wrong type arg' exceptions with IPv6 addresses
  * Fix typos in `(srfi srfi-19)'
  * Have `(srfi srfi-35)' provide named struct vtables
  * Fix C documentation extraction ("snarfing") with recent GCC
  versions
  * Fix some Interix build problems
  * Fix Tru64 build problems
  * Fix GC-related build issues on Solaris 10 x86 with Sun Studio 12.
  * Several small documentation fixes.
* Mon Mar 22 2010 pgajdos@suse.cz
- fixed build with new gcc
* Tue Jan 26 2010 pgajdos@suse.cz
- fixed build:
  "Earlier versions of ltdl would look for extensions under $PWD; this
  behavior changed in 2.2.6b."
  * testsuite-build.patch taken from guile git (1.8 branch)
* Mon Nov 30 2009 pgajdos@suse.cz
- updated to 1.8.7 (see NEWS)
- fixed testsuite with patch taken from Fedora
  * popen-test.patch
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Jun 16 2009 pgajdos@suse.cz
- Updated to 1.8.6 (see NEWS)
  - removed ac.patch
* Sat Feb  7 2009 schwab@suse.de
- Rebuild broken info files.
- Fix %%post scripts.
* Fri Jan 16 2009 crrodriguez@suse.de
-  remove static libraries
- run make check
* Sun Sep  7 2008 schwab@suse.de
- Fix conflicting options.
* Mon Jul  7 2008 pgajdos@suse.cz
- updated to 1.8.5:
  * new modules `(srfi srfi-88)'
  * New `postfix' read option, for SRFI-88 keyword syntax
  * Some I/O primitives have been inlined, which improves I/O performance
  * New object-based traps infrastructure
  * New support for working on Guile code from within Emacs
  * bug fixes
* Thu Mar 13 2008 schwab@suse.de
- Use autoreconf.
* Thu Feb 28 2008 ro@suse.de
- update to 1.8.4:
  * New modules (srfi srfi-69)
  * Bug fixes
- fix code for recent gcc by checking for __GNUC_GNU_INLINE__
  instead of __GNUC__ for inline specifics (thanks, richi)
* Mon Feb  4 2008 pgajdos@suse.cz
- guile conflicts with slib < 3a5 [#354936]
* Wed Dec 12 2007 pgajdos@suse.cz
- upgraded to 1.8.3:
  * New modules (srfi srfi-35), (srfi srfi-37)
  * Bug fixes
  * The reader is now faster, which reduces startup time
  * Procedures returned by `record-accessor' and `record-modifier'
    are faster
  * New procedures set-program-arguments, make-vtable
  * Incompatible change:
    ~~~~~~~~~~~~~~~~~~~~
    The body of a top-level `define' no longer sees the binding
    being created. In a top-level `define', the binding being
    created is no longer visible from the `define' body. This
    breaks code like "(define foo (begin (set! foo 1) (+ foo 1)))",
    where `foo' is now unbound in the body. However, such code
    was not R5RS-compliant anyway, per Section 5.2.1.
- removed getcontext.patch -- no longer needed because
  of code change
* Mon Mar  5 2007 sbrabec@suse.cz
- Slib guile library installation moved from guile to slib.
* Thu Jan 11 2007 sbrabec@suse.cz
- More spec file cleanups.
* Fri Dec  8 2006 maw@suse.de
- Clean up the spec, removing some hardcoded paths.
* Tue Nov 28 2006 sbrabec@suse.cz
- Build as user and do not alter root filesystem.
* Mon Nov 27 2006 sbrabec@suse.cz
- Created empty directory for site packages (#223837).
* Thu Nov 23 2006 sbrabec@suse.cz
- Fixed slib installation scriptlets (#214940).
* Wed Nov  8 2006 anicka@suse.cz
- moved .la files to the base package (#218032).
* Wed Oct 25 2006 sbrabec@suse.cz
- Moved .so files to the base package (#214940).
* Mon Oct 16 2006 anicka@suse.cz
- move /usr/share/guile from devel to main package
  (fixes ##212545)
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Fri Oct 13 2006 schwab@suse.de
- Add split provide.
* Fri Oct 13 2006 aj@suse.de
- Split up devel subpackage.
* Tue Oct 10 2006 sbrabec@suse.cz
- Updated to version 1.8.1:
  * LFS functions are now used to access 64-bit files on 32-bit
    systems.
  * New procedures and functions.
  * New modules and module merges.
  * API changes.
  * Bugs fixed.
  * Guile is now licensed with the GNU Lesser General
    Public License.
  * The manual is now licensed with the GNU Free Documentation
    License.
  * Guile now requires GNU MP.
  * Guile now has separate private and public configuration
    headers.
  * Thread implementation has changed.
  * Command line syntax changes.
* Fri Oct  6 2006 anicka@suse.cz
- update to 1.6.8
  * gcc 4.0 fixes
  * Guile now allows multiple line comments to end without
    a trailing newline.
  * better support for new versions of SLIB
  * changes in C interface
* Fri Sep  8 2006 anicka@suse.cz
- rewrite SuSEconfig.guile to RPM triggers
* Sun Jul 16 2006 schwab@suse.de
- Mark ia64_getcontext as returning twice.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 ro@suse.de
- add aclocal in libltdl
* Wed May 18 2005 sbrabec@suse.cz
- Disabled randomly failing make -j.
* Tue Apr  5 2005 sbrabec@suse.cz
- Fixed incomplete array element type.
* Thu Mar 24 2005 uli@suse.de
- fixed to build on ARM
* Fri Jan 21 2005 sbrabec@suse.cz
- Updated to version 1.6.7.
* Fri Dec 10 2004 meissner@suse.de
- make -j , added make check.
* Tue Mar 30 2004 sbrabec@suse.cz
- Fixed tempfile creation in guile-snarf (#36367).
- Build with -fno-strict-aliasing.
* Thu Nov  6 2003 schwab@suse.de
- Fix syntax in configure script.
* Tue Jul  8 2003 sbrabec@suse.cz
- Updated to version 1.6.4.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Wed Mar 12 2003 sbrabec@suse.cz
- Workaround guile-config info version bug (symlink, fixes bug 25190).
* Tue Feb 11 2003 sbrabec@suse.cz
- Fixed GUILEVERSION datadir path.
* Mon Feb 10 2003 sbrabec@suse.cz
- Updated to version 1.6.2.
- Use %%install_info (bug #23423).
* Wed Dec 11 2002 garloff@suse.de
- Make slib integration work independent of guile version number.
* Wed Dec  4 2002 sbrabec@suse.cz
- Change error message for unknown platform to warning. It allows to
  compile guile on all platforms, but there is no guarantee to
  functionallity. (guile-platforms.diff)
* Tue Dec  3 2002 sbrabec@suse.cz
- Fixed typo, which breaks TeXmacs
  (guile-1.6.0-top_srcdir_absolute.diff).
* Wed Oct 30 2002 sbrabec@suse.cz
- Update to version 1.6.0.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Tue Jul 30 2002 mcihar@suse.cz
- fixed SuSEconfig.guile for new version
* Wed Jul 17 2002 tiwai@suse.de
- updated to version 1.4.1.
* Tue Jun 11 2002 mcihar@suse.cz
- disabled qthreads for ppc64
* Mon Apr 29 2002 sf@suse.de
- disabled qthreads for x86_64
* Thu Apr  4 2002 pmladek@suse.cz
- moved AC_LIBOBJ after AC_PROG_CC because AC_LIBOBJ uses $ac_objext
* Wed Apr  3 2002 pmladek@suse.cz
- fixed to compile with autoconf-2.53 (AC_LIBOBJ vs. LIBOBJS)
* Fri Feb  8 2002 pmladek@suse.cz
- used -a option with automake to fix for PLUS distribution
- added back guile-doc-snarf: work around problem with cpp on ia64
  bebause of 7.2-ia64+kde distribution
* Wed Feb  6 2002 schwab@suse.de
- Don't add /usr/include and /usr/local/include to include search path.
- Avoid trigraph.
- Add support for ia64 register backing store (from cvs).
- Don't build with -O0 on ia64.
* Mon Dec 17 2001 froh@suse.de
- added %%{_libdir} to the specfile where appropriate to make it lib64
  clean.
* Fri Dec  7 2001 pmladek@suse.cz
- fixed for new position of slib library
- SuSEconfig.guile uses check_md5_and_move now
- removed unused package scheme from neededforbuild
* Tue Nov  6 2001 pmladek@suse.cz
- fixed to compile with automake 1.5:
  * OMIT_DEPENDENCIES are not supported now
* Sat Sep 15 2001 schwab@suse.de
- Fix libtool configuration.
- Remove ia64 cpp workaround.
- Fix hash functions for 64-bit architectures.
* Fri Aug 31 2001 pmladek@suse.cz
- fixed creating of SLIB catalog (#8997):
  - moved from triggerin to SuSEconfig because
  there were problems with update when rpm was
  updated after guile
* Mon Aug 27 2001 pmladek@suse.cz
- fixed to compile on axp:
  * fixed file numbering in qt/md/axp.s
  * fixed end of block qt_vstart in qt/md/axp.s
* Fri Aug 10 2001 ro@suse.de
- fixed to build with current autoconf and libtool
* Thu Jun 14 2001 pmladek@suse.cz
- fixed to more correctly compile with new autoconf
* Mon Jun 11 2001 pmladek@suse.cz
- fixed to compile with new autoconf
* Sat May 12 2001 schwab@suse.de
- Fix readline interface.
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Wed Dec  6 2000 schwab@suse.de
- guile-doc-snarf: work around problem with cpp on ia64.
- Build with -O0 on ia64.
* Thu Nov 23 2000 cihlar@suse.cz
- fixed to compile on older distros
* Sun Nov 12 2000 ro@suse.de
- don't redeclare inet_aton
* Wed Nov  8 2000 ro@suse.de
- changed %%post to %%triggerin -- scheme
* Tue Nov  7 2000 cihlar@suse.cz
- added postinstall and link to /usr/lib/scheme/slib
* Fri Nov  3 2000 cihlar@suse.cz
- bzipped sources
- clean up spec file
* Mon Oct 23 2000 ro@suse.de
- use macro for infodir
* Wed Aug  2 2000 cihlar@suse.cz
- update to version 1.4
* Fri Apr  7 2000 bk@suse.de
- And no QuickThreads yet on s390 too ;-)
* Thu Apr  6 2000 schwab@suse.de
- No QuickThreads yet on ia64.
* Mon Mar  6 2000 schwab@suse.de
- Update config.{guess,sub} from automake.
* Sun Feb  6 2000 ke@suse.de
- Add group tag.
- /configure -> %%build.
- use /usr/share/info.
* Sun Oct  3 1999 ke@suse.de
- update: 1.3.4.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Sep  7 1999 uli@suse.de
- no QuickThreads on PPC, disabled them
* Wed Aug 25 1999 ro@suse.de
- fixed configuration for alpha-Quickthreads again
* Wed Aug 25 1999 ke@suse.de
- update: 1.3.2.
* Wed Mar 17 1999 ro@suse.de
- fixed patch-call
* Wed Feb 10 1999 ke@suse.de
- apply guile-slow-read-fix.patch (by Harvey J. Stein
  <hjstein@bfr.co.il>).
- fix lib perms.
* Fri Feb  5 1999 ro@suse.de
- changed config to detect alpha(ev56)  as alpha
* Wed Oct 21 1998 ke@suse.de
- update: version 1.3.
- build libqthreads.
* Wed Sep 23 1998 ke@suse.de
- update: snapshot 1998-09-23 (1.3a).
* Sun Aug 23 1998 ke@suse.de
- update: snapshot 1998-08-23 (1.3a).
* Fri Nov 21 1997 bs@suse.de
- don't call ldconfig in spec file
* Tue Jul 15 1997 Karl Eichwalder  <ke@suse.de>
  * initial package: version 1.2.
